DataLad CDS extension
*********************

This is a DataLad extension that enables fetching of data from the Copernicus Climate Data Store
in a way that is tightly integrated with DataLad and git-annex.


API
===

High-level API commands
-----------------------

.. toctree::
   :maxdepth: 2

   python_reference.rst


Command line reference
----------------------

.. toctree::
   :maxdepth: 2

   cli_reference.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
